(redirect-result _)Returns a UserCredential from the redirect-based sign-in flow. If sign-in succeeded, returns the signed in user. If sign-in was unsuccessful, fails with an error. If no redirect operation was called, returns a UserCredential with a null User.
Returns a UserCredential from the redirect-based sign-in flow. If sign-in succeeded, returns the signed in user. If sign-in was unsuccessful, fails with an error. If no redirect operation was called, returns a UserCredential with a null User.
(check-actioncode _ code)Checks a verification code sent to the user by email or other out-of-band mechanism.
Checks a verification code sent to the user by email or other out-of-band mechanism.
(auth-changed _ observer)(auth-changed _ observer failure)(auth-changed _ observer failure complete)Adds an observer for auth state changes.
Adds an observer for auth state changes.
(login-popup _ provider)Authenticates a Firebase client using a popup-based OAuth authentication flow.
Authenticates a Firebase client using a popup-based OAuth authentication flow.
(create-user _ email pass)Creates a new user account associated with the specified email address and password.
Creates a new user account associated with the specified email address and password.
(current-user _)The currently signed-in user (or null).
The currently signed-in user (or null).
(providers-by-email _ email)Gets the list of provider IDs that can be used to sign in for the given email address. Useful for an 'identifier-first' sign-in flow.
Gets the list of provider IDs that can be used to sign in for the given email address. Useful for an 'identifier-first' sign-in flow.
(login-token _ token)Asynchronously signs in using a custom token. Custom tokens are used to integrate Firebase Auth with existing auth systems, and must be generated by the auth backend.
Asynchronously signs in using a custom token. Custom tokens are used to integrate Firebase Auth with existing auth systems, and must be generated by the auth backend.
(logout _)Signs out the current user.
Signs out the current user.
(login-redirect _ provider)Authenticates a Firebase client using a full-page redirect flow.
Authenticates a Firebase client using a full-page redirect flow.
(login-userpass _ email pass)Asynchronously signs in using an email and password.
Asynchronously signs in using an email and password.
(apply-actioncode _ code)Applies a verification code sent to the user by email or other out-of-band mechanism.
Applies a verification code sent to the user by email or other out-of-band mechanism.
(login-cred _ cred)Asynchronously signs in with the given credentials.
Asynchronously signs in with the given credentials.
(confirm-pass-reset _ code pass)Completes the password reset process, given a confirmation code and new password.
Completes the password reset process, given a confirmation code and new password.
(send-pass-reset _ email)Sends a password reset email to the given email address.
Sends a password reset email to the given email address.
(get-app _)The App associated with the Auth service instance.
The App associated with the Auth service instance.
(login-anon _)Asynchronously signs in as an anonymous user. If there is already an anonymous user signed in, that user will be returned; otherwise, a new anonymous user identity will be created and returned.
Asynchronously signs in as an anonymous user. If there is already an anonymous user signed in, that user will be returned; otherwise, a new anonymous user identity will be created and returned.
(verify-pass-reset _ code)Checks a password reset code sent to the user by email or other out-of-band mechanism.
Checks a password reset code sent to the user by email or other out-of-band mechanism.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |