(get-refreshtoken _)A refresh token for the user account. Use only for advanced scenarios that require explicitly refreshing tokens.
A refresh token for the user account. Use only for advanced scenarios that require explicitly refreshing tokens.
(get-token _)(get-token _ refresh)Returns a JWT token used to identify the user to a Firebase service.
Returns a JWT token used to identify the user to a Firebase service.
(send-verification _)Sends a verification email to a user.
Sends a verification email to a user.
(unlink _ provider)Unlinks a provider from a user account.
Unlinks a provider from a user account.
(link-popup _ provider)Links the authenticated provider to the user account using a pop-up based OAuth flow.
Links the authenticated provider to the user account using a pop-up based OAuth flow.
(link-redirect _ provider)Links the authenticated provider to the user account using a full-page redirect flow.
Links the authenticated provider to the user account using a full-page redirect flow.
(remove _)Deletes and signs out the user.
Deletes and signs out the user.
(reauthenticate _ cred)Re-authenticates a user using a fresh credential.
Re-authenticates a user using a fresh credential.
(update-email _ email)Updates the user's email address.
Updates the user's email address.
(get-providerdata _)Additional provider-specific information about the user.
Additional provider-specific information about the user.
(update-password _ pass)Updates the user's password.
Updates the user's password.
(update-profile _ profile)Updates a user's profile data.
Updates a user's profile data.
(verified? _)True if the user's email address has been verified.
True if the user's email address has been verified.
(anonymous? _)True if user is anonymous.
True if user is anonymous.
(link _ cred)Links the user account with the given credentials.
Links the user account with the given credentials.
(reload _)Refreshes the current user, if signed in.
Refreshes the current user, if signed in.
(email _)The user's email address (if available).
The user's email address (if available).
(name _)The user's display name (if available).
The user's display name (if available).
(photo-url _)The URL of the user's profile picture (if available).
The URL of the user's profile picture (if available).
(providerid _)The authentication provider ID for the current user. For example, 'facebook.com', or 'google.com'.
The authentication provider ID for the current user. For example, 'facebook.com', or 'google.com'.
(uid _)The user's unique ID.
The user's unique ID.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |